from _typeshed import Incomplete

class WorksheetCopy:
    source: Incomplete
    target: Incomplete
    def __init__(self, source_worksheet, target_worksheet) -> None: ...
    def copy_worksheet(self) -> None: ...
