from _typeshed import Incomplete

from openpyxl.descriptors.serialisable import Serialisable

class GraphicalProperties(Serialisable):
    tagname: str
    bwMode: Incomplete
    xfrm: Incomplete
    transform: Incomplete
    custGeom: Incomplete
    prstGeom: Incomplete
    noFill: Incomplete
    solidFill: Incomplete
    gradFill: Incomplete
    pattFill: Incomplete
    ln: Incomplete
    line: Incomplete
    scene3d: Incomplete
    sp3d: Incomplete
    shape3D: Incomplete
    extLst: Incomplete
    __elements__: Incomplete
    def __init__(
        self,
        bwMode: Incomplete | None = ...,
        xfrm: Incomplete | None = ...,
        noFill: Incomplete | None = ...,
        solidFill: Incomplete | None = ...,
        gradFill: Incomplete | None = ...,
        pattFill: Incomplete | None = ...,
        ln: Incomplete | None = ...,
        scene3d: Incomplete | None = ...,
        custGeom: Incomplete | None = ...,
        prstGeom: Incomplete | None = ...,
        sp3d: Incomplete | None = ...,
        extLst: Incomplete | None = ...,
    ) -> None: ...
