from _typeshed import Incomplete

class Comment:
    content: Incomplete
    author: Incomplete
    height: Incomplete
    width: Incomplete
    def __init__(self, text, author, height: int = ..., width: int = ...) -> None: ...
    @property
    def parent(self): ...
    def __eq__(self, other): ...
    def __copy__(self): ...
    def bind(self, cell) -> None: ...
    def unbind(self) -> None: ...
    @property
    def text(self): ...
    @text.setter
    def text(self, value) -> None: ...
