from _typeshed import Incomplete

MIN_ROW: int
MIN_COLUMN: int
MAX_COLUMN: int
MAX_ROW: int
PACKAGE_PROPS: str
PACKAGE_XL: str
PACKAGE_RELS: str
PACKAGE_THEME: Incomplete
PACKAGE_WORKSHEETS: Incomplete
PACKAGE_CHARTSHEETS: Incomplete
PACKAGE_DRAWINGS: Incomplete
PACKAGE_CHARTS: Incomplete
PACKAGE_IMAGES: Incomplete
PACKAGE_WORKSHEET_RELS: Incomplete
PACKAGE_CHARTSHEETS_RELS: Incomplete
PACKAGE_PIVOT_TABLE: Incomplete
PACKAGE_PIVOT_CACHE: Incomplete
ARC_CONTENT_TYPES: str
ARC_ROOT_RELS: Incomplete
ARC_WORKBOOK_RELS: Incomplete
ARC_CORE: Incomplete
ARC_APP: Incomplete
ARC_WORKBOOK: Incomplete
ARC_STYLE: Incomplete
ARC_THEME: Incomplete
ARC_SHARED_STRINGS: Incomplete
ARC_CUSTOM_UI: str
XML_NS: str
DCORE_NS: str
DCTERMS_NS: str
DCTERMS_PREFIX: str
DOC_NS: str
REL_NS: Incomplete
COMMENTS_NS: Incomplete
IMAGE_NS: Incomplete
VML_NS: Incomplete
VTYPES_NS: Incomplete
XPROPS_NS: Incomplete
EXTERNAL_LINK_NS: Incomplete
PKG_NS: str
PKG_REL_NS: Incomplete
COREPROPS_NS: Incomplete
CONTYPES_NS: Incomplete
XSI_NS: str
SHEET_MAIN_NS: str
CHART_NS: str
DRAWING_NS: str
SHEET_DRAWING_NS: str
CHART_DRAWING_NS: str
CUSTOMUI_NS: str
NAMESPACES: Incomplete
WORKBOOK_MACRO: str
WORKBOOK: str
SPREADSHEET: str
SHARED_STRINGS: Incomplete
EXTERNAL_LINK: Incomplete
WORKSHEET_TYPE: Incomplete
COMMENTS_TYPE: Incomplete
STYLES_TYPE: Incomplete
CHARTSHEET_TYPE: Incomplete
DRAWING_TYPE: str
CHART_TYPE: str
CHARTSHAPE_TYPE: str
THEME_TYPE: str
XLTM: Incomplete
XLSM: Incomplete
XLTX: Incomplete
XLSX: Incomplete
EXT_TYPES: Incomplete
CTRL: str
ACTIVEX: str
VBA: str
