from _typeshed import Incomplete

def read_dimension(source): ...

class ReadOnlyWorksheet:
    cell: Incomplete
    iter_rows: Incomplete
    @property
    def values(self): ...
    @property
    def rows(self): ...
    __getitem__: Incomplete
    __iter__: Incomplete
    parent: Incomplete
    title: Incomplete
    sheet_state: str
    def __init__(self, parent_workbook, title, worksheet_path, shared_strings) -> None: ...
    def calculate_dimension(self, force: bool = ...): ...
    def reset_dimensions(self) -> None: ...
    @property
    def min_row(self): ...
    @property
    def max_row(self): ...
    @property
    def min_column(self): ...
    @property
    def max_column(self): ...
